/*
  AntiRight
  (c) 2007 Jeffrey Bedard
  antiright@gmail.com

  This file is part of AntiRight.

  AntiRight is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; either version 2 of the License, or
  (at your option) any later version.

  AntiRight is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with AntiRight; if not, write to the Free Software
  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
*/

#ifndef GSHTERM_COMMAND_LINE_H
#define GSHTERM_COMMAND_LINE_H

#include "gshterm.h"

gboolean
gshterm_construct_command_from_args(
	struct GSHTerm *term, int argc, char **argv, gchar **command);

char*
gshterm_construct_command(struct GSHTerm *term, int argc, char **argv);

#endif /* GSHTERM_COMMAND_LINE_H */

